@@ -1,7 +1,7 @@
 #![no_std]
 #[macro_use]
 extern crate generic_array;
-use generic_array::typenum::{U3, U97};
+use generic_array::typenum::{U1, U3, U97};
 use generic_array::GenericArray;
 use core::ops::Drop;
 
@@ -11,7 +11,7 @@ fn test() {
     for i in 0..97 {
         list97[i] = i as i32;
     }
-    let l : GenericArray<i32, U97> = GenericArray::clone_from_slice(&list97);
+    let l: GenericArray<i32, U97> = GenericArray::clone_from_slice(&list97);
     assert_eq!(l[0], 0);
     assert_eq!(l[1], 1);
     assert_eq!(l[32], 32);
@@ -42,7 +42,7 @@ fn test_drop() {
         let _: GenericArray<TestDrop, U3> = arr![TestDrop; TestDrop(1), TestDrop(2), TestDrop(3)];
     }
     unsafe {
-        assert_eq!(drop_counter, 6);    // 6 drops, as explained above
+        assert_eq!(drop_counter, 6); // 6 drops, as explained above
     }
 }
 
@@ -63,34 +63,42 @@ fn test_copy() {
 
 #[test]
 fn test_iter_flat_map() {
-    assert!((0..5).flat_map(|i| arr![i32; 2 * i, 2 * i + 1]).eq(0..10));
+    assert!((0..5)
+                .flat_map(|i| arr![i32; 2 * i, 2 * i + 1])
+                .eq(0..10));
 }
 
 #[test]
 fn test_from_slice() {
-    let arr = [1,2,3,4];
+    let arr = [1, 2, 3, 4];
     let gen_arr = GenericArray::<_, U3>::from_slice(&arr[..3]);
     assert_eq!(&arr[..3], gen_arr.as_slice());
 }
 
 #[test]
 fn test_from_mut_slice() {
-    let mut arr = [1,2,3,4];
+    let mut arr = [1, 2, 3, 4];
     {
         let mut gen_arr = GenericArray::<_, U3>::from_mut_slice(&mut arr[..3]);
         gen_arr[2] = 10;
     }
-    assert_eq!(arr, [1,2,10,4]);
+    assert_eq!(arr, [1, 2, 10, 4]);
 }
 
 #[test]
-fn test_unit_macro(){
+fn test_default() {
+    let arr = GenericArray::<u8, U1>::default();
+    assert_eq!(arr[0], 0);
+}
+
+#[test]
+fn test_unit_macro() {
     let arr = arr![f32; 3.14];
     assert_eq!(arr[0], 3.14);
 }
 
 #[test]
-fn test_empty_macro(){
+fn test_empty_macro() {
     let arr = arr![f32;];
 }
 
@@ -99,7 +107,6 @@ fn test_empty_macro(){
 // fn test_empty_macro2(){
 //     let arr = arr![];
 // }
-
 #[cfg(feature="serde")]
 mod impl_serde {
     extern crate serde_json;
